@@ -1,14 +1,10 @@
 import ssl
 import urllib.request
-from m3u8.parser import urljoin
 
-
-def _parsed_url(url):
-    return urljoin(url, '.')
+from urllib.parse import urljoin
 
 
 class DefaultHTTPClient:
-
     def __init__(self, proxies=None):
         self.proxies = proxies
 
@@ -18,7 +14,7 @@ class DefaultHTTPClient:
         opener = urllib.request.build_opener(proxy_handler, https_handler)
         opener.addheaders = headers.items()
         resource = opener.open(uri, timeout=timeout)
-        base_uri = _parsed_url(resource.geturl())
+        base_uri = urljoin(resource.geturl(), ".")
         content = resource.read().decode(
             resource.headers.get_content_charset(failobj="utf-8")
         )
@@ -26,7 +22,6 @@ class DefaultHTTPClient:
 
 
 class HTTPSHandler:
-
     def __new__(self, verify_ssl=True):
         context = ssl.create_default_context()
         if not verify_ssl:
